pub struct NetworkConfig {
pub mode: NetworkMode,
pub max_peers: u32,
}Expand description
Configuration for the networking subsystem.
Used with [GameBuilder::with_network].
Fields
mode: NetworkModemax_peers: u32Implementations
Sourceimpl NetworkConfig
impl NetworkConfig
Sourcepub fn host(port: u16) -> NetworkConfig
pub fn host(port: u16) -> NetworkConfig
Convenience: host on a given port with default max peers.
Sourcepub fn client(addr: impl Into<String>) -> NetworkConfig
pub fn client(addr: impl Into<String>) -> NetworkConfig
Convenience: connect to a remote address with default max peers.